Srho.ts and surrogate data obtained through the sieve bootstrap.Srho.test.AR(x, y, lag.max = 10, B = 100, plot = TRUE, quant = c(0.95, 0.99), bw = c("reference", "mlcv", "lscv"), method = c("integral", "summation"), maxpts = 0, tol = 0.001, order.max = 10, fit.method=c("yule-walker", "burg", "ols", "mle", "yw"), smoothed = TRUE)y is missing in the univariate case).trunc(N/4) where N is the number of observations.TRUE (the default) produces a plot of Srho together with confidence bands under the null hypothesis of linearity at 95% and 99%.Srho.ts.Srho.ts.Srho.ts.Srho.ts.surrogate.ARs.surrogate.ARs.TRUE (the default) uses the smoothed sieve bootstrap in surrogate.ARs to generate surrogates. Otherwise uses the classic sieve by calling surrogate.AR.lag.max elements containing Srho computed at each lag.call:"call": contains the call to the routine.call.h:"call": contains the call to the routine used for obtaining the surrogates or the bootstrap replicates under the null hypothesis"matrix": contains the quantiles of the surrogate distribution under the null hypothesis.test.type"character": contains a description of the type of test performed."list": contains the lags at which Srho exceeds the confidence bands at quant% under the null hypothesis."numeric": contains the bootstrap p-value for each lag."logical": TRUE if the stationary version is computed. Set to FALSE by default as only the non-stationary version is implemented."character": contains the data type."character": additional notes.lag.max Srho.test.AR computes a test for nonlinearity for time series based
on Srho.ts. The distribution under the null hypothesis of linearity is obtained through the sieve bootstrap.
Srho.ts, surrogate.ARs, surrogate.AR. See Srho.test.AR.p for the parallel version.## Not run:
# set.seed(1345)
# x <- arima.sim(n=120, model = list(ar=0.8));
# result <- Srho.test.AR(x, lag.max = 5, B = 10, bw='reference', method='integral')
# ## End(Not run)Run the code above in your browser using DataLab