Learn R Programming

tseriesEntropy (version 0.5-12)

Srho.ts: Entropy Measure Of Serial And Cross Dependence

Description

Entropy based measure of serial and cross dependence for continuous data. For integer/categorical data see Srho. Implements a normalized version of the Hellinger/Matusita distance. As shown in the references the metric measure is a proper distance.

Usage

Srho.ts(x, y, lag.max = 10, bw = c("reference", "mlcv", "lscv"), method = c("integral", "summation"), plot = TRUE, maxpts = 0, tol = 0.001)

Arguments

x, y
univariate numeric time series object or numeric vectors (y is missing in the univariate case).
lag.max
maximum lag at which to calculate Srho; default is 10
bw
Object of class "character": bandwidth selection method, can be "reference", "mlcv" or "lscv".
method
Object of class "character": computation method, can be "integral" or "summation".
plot
logical. If TRUE (the default) Srho is plotted.
maxpts
maximum number of function evaluations, passed to adaptIntegrate, defaults to 0 (unlimited).
tol
max. tolerance, passed to adaptIntegrate.

Value

.Data
Object of class "numeric": contains Srho computed on the data set.
method
Object of class "character": computation method
bandwidth
Object of class "character": bandwidth selection method.
lags
Object of class "integer": contains the lags at which Srho is computed.
stationary
Object of class "logical": TRUE if the stationary version is computed.
data.type
Object of class "character": contains the data type.
notes
Object of class "character": additional notes.

Details

Univariate version: serial entropy
Srho.ts(x, lag.max = 10,
 bw = c("reference", "mlcv", "lscv"), method = c("summation", "integral"),
 plot = TRUE, maxpts = 0, tol = 0.001)

Bivariate version: cross entropy
Srho.ts(x, y, lag.max = 10,
 bw = c("reference", "mlcv", "lscv"), method = c("summation", "integral"),
  plot = TRUE, maxpts = 0, tol = 0.001)

References

Granger C. W. J., Maasoumi E., Racine J., (2004) A dependence metric for possibly nonlinear processes. Journal of Time Series Analysis, 25(5), 649--669.

Maasoumi E., (1993) A compendium to information theory in economics and econometrics. Econometric Reviews, 12(2), 137--181.

Giannerini S., Maasoumi E., Bee Dagum E., (2015), Entropy testing for nonlinear serial dependence in time series, Biometrika, forthcoming.

See Also

Srho.test.ts, adaptIntegrate. The function Srho implements the same measure for integer/categorical data.

Examples

Run this code
set.seed(11)
x <- arima.sim(list(order = c(1,0,0), ar = 0.8), n = 50)
S <- Srho.ts(x,lag.max=5,method="integral",bw="mlcv")

# creates a nonlinear dependence at lag 1
y <- c(runif(1),x[-50]^2*0.8-0.3)
S <- Srho.ts(x,y,lag.max=3,method="integral",bw="mlcv")

Run the code above in your browser using DataLab